<?php

require_once( 'library/omg.php' );
require_once( 'library/social-nav.php' );


function omg_setup() {

  // let's get language support going, if you need it
  load_theme_textdomain( 'omg', get_template_directory() . '/library/translation' );

  // enqueue base scripts and styles
  add_action( 'wp_enqueue_scripts', 'omg_scripts_and_styles');
  // ie conditional wrapper

  // launching this stuff after theme setup
  omg_theme_support();

  // adding sidebars to WordPress (these are created in functions.php)
  add_action( 'widgets_init', 'omg_register_sidebars' );

  // cleaning up excerpt
  add_filter( 'excerpt_more', 'omg_excerpt_more' );

  /************* OEMBED SIZE OPTIONS *************/

  if ( ! isset( $content_width ) ) {
    $content_width = 640;
  }

} 

add_action( 'after_setup_theme', 'omg_setup' );

/************* THUMBNAIL SIZE OPTIONS *************/

// Thumbnail sizes
add_image_size( 'omg-thumb-600', 600, 150, true );
add_image_size( 'omg-thumb-300', 300, 100, true );
add_image_size( 'omg-slider-image', 1280, 500, true );
add_image_size( 'omg-thumb-image-300by300', 300, 300, true );


add_filter( 'image_size_names_choose', 'omg_custom_image_sizes' );
function omg_custom_image_sizes( $sizes ) {
    return array_merge( $sizes, array(
        'omg-thumb-600' => '600px by 150px',
        'omg-thumb-300' => '300px by 100px',
        'omg-slider-image' => '1280px by 500px'
    ) );
}

/************* ACTIVE SIDEBARS ********************/

// Sidebars & Widgetizes Areas
function omg_register_sidebars() {
  register_sidebar(array(
    'id' => 'sidebar1',
    'name' => __( 'Posts Sidebar', 'omg' ),
    'description' => __( 'The Posts sidebar.', 'omg' ),
    'before_widget' => '<div id="%1$s" class="widget %2$s">',
    'after_widget' => '</div>',
    'before_title' => '<h4 class="widgettitle">',
    'after_title' => '</h4>',
  ));

  register_sidebar(array(
    'id' => 'sidebar2',
    'name' => __( 'Page Sidebar', 'omg' ),
    'description' => __( 'The Page sidebar.', 'omg' ),
    'before_widget' => '<div id="%1$s" class="widget %2$s">',
    'after_widget' => '</div>',
    'before_title' => '<h4 class="widgettitle">',
    'after_title' => '</h4>',
  ));

  register_sidebar(array(
    'id' => 'sidebar3',
    'name' => __( 'Menu Widget Area', 'omg' ),
    'description' => __( 'The Menu Widget Area.', 'omg' ),
    'before_widget' => '<div id="%1$s" class="widget %2$s">',
    'after_widget' => '</div>',
    'before_title' => '<h4 class="widgettitle">',
    'after_title' => '</h4>',
  ));


} // don't remove this bracket!

/************* COMMENT LAYOUT *********************/

// Comment Layout
function omg_comments( $comment, $args, $depth ) {
    ?>
  <div id="comment-<?php comment_ID(); ?>" <?php comment_class('cf'); ?>>
    <article  class="cf">
      <header class="comment-author vcard">
        <?php
        /*
          this is the new responsive optimized comment image. It used the new HTML5 data-attribute to display comment gravatars on larger screens only. What this means is that on larger posts, mobile sites don't have a ton of requests for comment images. This makes load time incredibly fast! If you'd like to change it back, just replace it with the regular wordpress gravatar call:
          echo get_avatar($comment,$size='32',$default='<path_to_url>' );
        */
        ?>
        <?php // custom gravatar call ?>
        <?php
          // create variable
          $bgauthemail = get_comment_author_email();
        ?>
        <img data-gravatar="//www.gravatar.com/avatar/<?php echo md5( $bgauthemail ); ?>?s=100" class="load-gravatar avatar avatar-48 photo" height="100" width="100" src="" alt="gravatar" />
        <?php // end custom gravatar call ?>
      </header>
      <?php if ($comment->comment_approved == '0') : ?>
        <div class="alert alert-info">
          <p><?php _e( 'Your comment is awaiting moderation.', 'omg' ) ?></p>
        </div>
      <?php endif; ?>
      <section class="comment_content cf">
        <?php printf(__( '<cite class="fn">%1$s</cite> %2$s', 'omg' ), get_comment_author_link(), edit_comment_link(__( '(Edit)', 'omg' ),'  ','') ) ?>
        <br>
        <time datetime="<?php echo comment_time('Y-m-j'); ?>"><a href="<?php echo htmlspecialchars( get_comment_link( $comment->comment_ID ) ) ?>"><?php comment_time(__( 'F jS, Y', 'omg' )); ?> </a></time>
        <?php comment_text() ?>
        <?php comment_reply_link(array_merge( $args, array('depth' => $depth, 'max_depth' => $args['max_depth']))) ?>
      </section>
    </article>
  <?php // </li> is added by WordPress automatically ?>
<?php
} // don't remove this bracket!

function omg_fonts() {
  wp_enqueue_style('omg_raleway_fonts', get_template_directory_uri() . '/fonts/fonts.css');
}

add_action('wp_print_styles', 'omg_fonts');

/*******************************************************************
* These are settings for the Theme Customizer in the admin panel. 
*******************************************************************/
if ( ! function_exists( 'omg_theme_customizer' ) ) :
  function omg_theme_customizer( $wp_customize ) {
  
    /* color scheme option */
    $wp_customize->add_setting( 'omg_color_settings', array (
      'default' => '#222222',
      'sanitize_callback' => 'sanitize_hex_color',
    ) );
    
    $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'omg_color_settings', array(
      'label'    => __( 'Primary Color Scheme', 'omg' ),
      'section'  => 'colors',
      'settings' => 'omg_color_settings',
    ) ) );

    $wp_customize->add_setting( 'omg_color_settings_2', array (
      'default' => '#656565',
      'sanitize_callback' => 'sanitize_hex_color',
    ) );

    $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'omg_color_settings_2', array(
      'label'    => __( 'Secondary Color Scheme', 'omg' ),
      'section'  => 'colors',
      'settings' => 'omg_color_settings_2',
    ) ) );

    $wp_customize->add_setting( 'omg_color_settings_3', array (
      'default' => '#309DC1',
      'sanitize_callback' => 'sanitize_hex_color',
    ) );

    $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'omg_color_settings_3', array(
      'label'    => __( 'Button and link Color Scheme', 'omg' ),
      'section'  => 'colors',
      'settings' => 'omg_color_settings_3',
    ) ) );

    
    /* slider options */
    
    $wp_customize->add_section( 'omg_slider_section' , array(
      'title'       => __( 'Slider Options', 'omg' ),
      'priority'    => 33,
      'description' => __( 'Adjust the behavior of the image slider.', 'omg' ),
    ) );
    
    $wp_customize->add_setting( 'omg_slider_effect', array(
      'default' => 'scrollHorz',
      'capability' => 'edit_theme_options',
      'sanitize_callback' => 'sanitize_text_field',
    ));
    
    $wp_customize->add_control( 'effect_select_box', array(
      'settings' => 'omg_slider_effect',
      'label' => __( 'Select Effect:', 'omg' ),
      'section' => 'omg_slider_section',
      'type' => 'select',
      'choices' => array(
        'scrollHorz' => __( 'Horizontal (Default)', 'omg' ),
        'scrollVert' => __( 'Vertical', 'omg' ),
        'tileSlide' => __( 'Tile Slide', 'omg' ),
        'tileBlind' => __( 'Blinds', 'omg' ),
        'shuffle' => __( 'Shuffle', 'omg' ),
      ),
    ));
    
    $wp_customize->add_setting( 'omg_slider_timeout', array (
      'sanitize_callback' => 'omg_sanitize_integer',
    ) );
    
    $wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'omg_slider_timeout', array(
      'label'    => __( 'Autoplay Speed in Seconds', 'omg' ),
      'section'  => 'omg_slider_section',
      'settings' => 'omg_slider_timeout',
    ) ) );

     /* author bio in posts option */
    $wp_customize->add_section( 'omg_author_bio_section' , array(
      'title'       => __( 'Disable Author Bio', 'omg' ),
      'priority'    => 35,
      'description' => __( 'Option to disable the author bio in the posts.', 'omg' ),
    ) );
    
    $wp_customize->add_setting( 'omg_author_bio', array (
      'sanitize_callback' => 'omg_sanitize_checkbox',
    ) );
    
    $wp_customize->add_control('author_bio', array(
      'settings' => 'omg_author_bio',
      'label' => __('Disable the Author Bio?', 'omg'),
      'section' => 'omg_author_bio_section',
      'type' => 'checkbox',
    ));

    /* related posts option */
    $wp_customize->add_section( 'omg_related_posts_section' , array(
      'title'       => __( 'Disable Related Posts', 'omg' ),
      'priority'    => 36,
      'description' => __( 'Option to disable the related posts in the posts.', 'omg' ),
    ) );
    
    $wp_customize->add_setting( 'omg_related_posts', array (
      'sanitize_callback' => 'omg_sanitize_checkbox',
    ) );
    
    $wp_customize->add_control('related_posts', array(
      'settings' => 'omg_related_posts',
      'label' => __('Disable the Related Posts?', 'omg'),
      'section' => 'omg_related_posts_section',
      'type' => 'checkbox',
    ));

  }
endif;
add_action('customize_register', 'omg_theme_customizer');


/**
 * Sanitize checkbox
 */
if ( ! function_exists( 'omg_sanitize_checkbox' ) ) :
  function omg_sanitize_checkbox( $input ) {
    if ( $input == 1 ) {
      return 1;
    } else {
      return '';
    }
  }
endif;


/**
 * Sanitize integer input
 */
if ( ! function_exists( 'omg_sanitize_integer' ) ) :
  function omg_sanitize_integer( $input ) {
    return absint($input);
  }
endif;
/**
* Apply Color Scheme
*/

function omg_apply_color() {
    if ( get_theme_mod('omg_color_settings') ) {
  ?>
  <style>
      .blog-list .item h2,.pagination .current,.article-header h1,body .info p.author,body .related h3, body #comments-title,body .related ul li .related-info h3
      ,body cite.fn,body .comment-reply-title,.sidebar .widgettitle,.sidebar .widget #wp-calendar td#today,article.archive .entry-content h3 a
      {color: <?php echo get_theme_mod('omg_color_settings'); ?>;}
      body .pagination li:first-child {border: 2px solid <?php echo get_theme_mod('omg_color_settings'); ?>;}
  </style>
  <?php
    }
     if ( get_theme_mod('omg_color_settings_2') ) { ?>
     <style>
      .blog-list .item .excerpt p,.blog-list .item .date,.blog-list .item time,.entry-content p,body .byline,body .info p.author-desc,
       body .related ul li .related-info p,body .comment time a,body .comment_content p,#sidebar1 .widget ul li,body #sidebar1 a,#sideba1 .widget #wp-calendar td
      {color: <?php echo get_theme_mod('omg_color_settings_2'); ?>;}
     </style>

    <?php }

    if ( get_theme_mod('omg_color_settings_3') ) { ?>
      <style>
        .blog-list .item a.read-more,button, html input[type="button"], input[type="reset"], input[type="submit"],.widget #wp-calendar caption,.blue-btn, .comment-reply-link, #submit
        {background:<?php echo get_theme_mod('omg_color_settings_3'); ?>; }
        .entry-content p a,body .pagination li a,.blog-list .item a[rel="author"],body .byline a,body .info p.author-desc a,
        body .related ul li a,body .comment-reply-link
        {color: <?php echo get_theme_mod('omg_color_settings_3'); ?>;}
      </style>
    <?php }
    
  }
add_action( 'wp_head', 'omg_apply_color' );

/*-----------------------------------------------------------------------------------*/
/* custom functions below */
/*-----------------------------------------------------------------------------------*/
define('THEMEURL', get_template_directory_uri());
define('IMAGES', THEMEURL.'/images'); 
define('JS', THEMEURL.'/js');
define('CSS', THEMEURL.'/css');

if(is_user_logged_in()){
  add_action( 'wp_head', 'omg_user_login' );
  function omg_user_login(){ ?>
    <style>#main-navigation{top: 30px!important;}</style>
    <?php
  }
}

/*get the author excerpt*/
function omg_author_excerpt() {
      $text_limit = 50; //Words to show in author bio excerpt
      $read_more  = __( 'Read More', 'omg' ); //Read more text
      $end_of_txt = "...";
      $url_of_author  = get_author_posts_url(get_the_author_meta('ID'));
      $short_desc_author = wp_trim_words(strip_tags(
                          get_the_author_meta('description')), $text_limit, 
                          $end_of_txt.'<br/>
                        <a href="'.$url_of_author.'" style="font-weight:bold;">'.$read_more .'</a>');

      return $short_desc_author;
}

/* catch the image inside a post */
function omg_catch_that_image() {
  global $post;
  $pattern = '|<img.*?class="([^"]+)".*?/>|';
  $transformed_content = apply_filters('the_content',$post->post_content);
  preg_match($pattern,$transformed_content,$matches);
  if (!empty($matches[1])) {
    $classes = explode(' ',$matches[1]);
    $id = preg_grep('|^wp-image-.*|',$classes);
    if (!empty($id)) {
      $id = str_replace('wp-image-','',$id);
      if (!empty($id)) {
        $id = reset($id);
        $transformed_content = wp_get_attachment_image($id,'full');  
        return $transformed_content;
      }
    }
  }
  
}

/* catch the image inside a post */
function omg_catch_that_image_thumb() {
  global $post;
  $pattern = '|<img.*?class="([^"]+)".*?/>|';
  $transformed_content = apply_filters('the_content',$post->post_content);
  preg_match($pattern,$transformed_content,$matches);
  if (!empty($matches[1])) {
    $classes = explode(' ',$matches[1]);
    $id = preg_grep('|^wp-image-.*|',$classes);
    if (!empty($id)) {
      $id = str_replace('wp-image-','',$id);
      if (!empty($id)) {
        $id = reset($id);
        $transformed_content = wp_get_attachment_image($id,'thumbnail');  
         return $transformed_content;
      }
    }
  }
 
}

/* catch the first image in a gallery*/
function omg_catch_gallery_image_full()  { 
    global $post;
    $gallery = get_post_gallery( $post, false );
    if ( !empty($gallery['ids']) ) {
      $ids = explode( ",", $gallery['ids'] );
      $total_images = 0;
      foreach( $ids as $id ) {
        
        $image  = wp_get_attachment_image( $id, 'full');
        $total_images++;
        
        if ($total_images == 1) {
          $first_img = $image;
          return $first_img;
        }
      }
    } 
}

/* catch the first image in a gallery*/
function omg_catch_gallery_image_thumb()  { 
    global $post;
    $gallery = get_post_gallery( $post, false );
    if ( !empty($gallery['ids']) ) {
      $ids = explode( ",", $gallery['ids'] );
      $total_images = 0;
      foreach( $ids as $id ) {
        
        $image  = wp_get_attachment_image( $id, 'thumbnail');
        $total_images++;
        
        if ($total_images == 1) {
          $first_img = $image;
          return $first_img;
        }
      }
    } 
}